@@ -1,4 +1,4 @@
-#' Mulitple Merge
+#' Multiple Merge
 #'
 #' Inspired by:
 #' https://www.r-bloggers.com/merging-multiple-data-files-into-one-data-frame/
@@ -8,6 +8,7 @@
 #'
 #' @return data.frame with merged files
 #' @importFrom utils read.csv
+#' @keywords internal
 multmerge <- function(filenames, sep = ",") {
   datalist <- lapply(filenames, function(x) {
     read.csv(file = x,
@@ -17,7 +18,12 @@ multmerge <- function(filenames, sep = ",") {
     })
   if (!validate_names(datalist))
     stop("Key translation is not the same in all files.")
-  Reduce(function(x, y) {merge(x, y, all = TRUE)}, datalist)
+  Reduce(
+    function(x, y) {
+      merge(x, y, all = TRUE)
+    },
+    datalist
+  )
 }
 
 #' Validate Column Names
@@ -29,6 +35,7 @@ multmerge <- function(filenames, sep = ",") {
 #'
 #' @return TRUE if names of n-th columns of data.frames is the same,
 #' FALSE otherwise.
+#' @keywords internal
 validate_names <- function(list_df, n = 1) {
   length(unique(sapply(list_df, function(x) names(x)[n]))) == 1
 }
@@ -42,9 +49,10 @@ validate_names <- function(list_df, n = 1) {
 #'
 #' @return data.frame with one column less
 #'
+#' @keywords internal
 column_to_row <- function(data, colname) {
   stopifnot(colname %in% colnames(data))
-  key_index <- which(colname == colnames( (data) ))
+  key_index <- which(colname == colnames((data)))
   ndata <- data[-key_index]
   rownames(ndata) <- data[, key_index]
   ndata
@@ -60,6 +68,7 @@ column_to_row <- function(data, colname) {
 #' @param warn_msg warning message to be displayed if \code{val} not in \code{vect}
 #'
 #' @return updated val
+#' @keywords internal
 check_value_presence <- function(val, vect, warn_msg = "") {
   if (!(val %in% vect)) {
     warning(warn_msg)
@@ -76,8 +85,9 @@ check_value_presence <- function(val, vect, warn_msg = "") {
 #' @param sep fields separator
 #'
 #' @return data.frame with CSV files content
+#' @keywords internal
 read_and_merge_csvs <- function(dir_path, sep = ",") {
-  all_files <- list.files(dir_path, pattern = ".*[.]csv$", full.names = TRUE)
+  all_files <- list.files(dir_path, pattern = "translation_.*[.]csv", full.names = TRUE)
   multmerge(all_files, sep)
 }
 
@@ -87,12 +97,12 @@ read_and_merge_csvs <- function(dir_path, sep = ",") {
 #'
 #' @return list of config options or empty list if file not exists
 #' @import yaml
+#' @keywords internal
 load_local_config <- function(yaml_config_path) {
   if (!is.null(yaml_config_path) &&
       file.exists(yaml_config_path)) {
     local_config <- yaml::yaml.load_file(yaml_config_path)
-  }
-  else {
+  } else {
     warning(paste0("You didn't specify config translation yaml file. ",
                    "Default settings are used."))
     local_config <- list()
